.. Hey Emacs, this is -*- rst -*-

   This file follows reStructuredText markup syntax; see
   http://docutils.sf.net/rst.html for more information.


`elasticluster.providers.openstack`
===================================
.. automodule:: elasticluster.providers.openstack
   :members:

